pub struct I2sRx<'d, Dm>where
Dm: DriverMode,{ /* private fields */ }Expand description
I2S RX channel.
Implementations
Sourceimpl<'d, Dm> I2sRx<'d, Dm>where
Dm: DriverMode,
impl<'d, Dm> I2sRx<'d, Dm>where
Dm: DriverMode,
Sourcepub fn read<BUF>(
self,
buffer: BUF,
) -> Result<I2sRxDmaTransfer<'d, Dm, BUF>, (Error, Self, BUF)>where
BUF: DmaRxBuffer,
pub fn read<BUF>(
self,
buffer: BUF,
) -> Result<I2sRxDmaTransfer<'d, Dm, BUF>, (Error, Self, BUF)>where
BUF: DmaRxBuffer,
Performs a DMA read.
The number of read bytes might be less than the capacity of the provided buffer since the peripheral might not completely fill each descriptor’s buffer.
Returns an I2sRxDmaTransfer.
Sourcepub fn apply_config(
&mut self,
rx_config: &UnitConfig,
) -> Result<(), ConfigError>
pub fn apply_config( &mut self, rx_config: &UnitConfig, ) -> Result<(), ConfigError>
Changes the I2S Rx unit configuration.